;;;; init.el --- Personal Init file -*- lexical-binding: t; -*-

;;;; Commentary:

;; Personal Emacs input file

;;;; Code:

;; Personal modules
(add-to-list 'load-path '"~/.dotfiles/emacs/.emacs.d/modules")

;; Slightly nicer theme
(set-face-attribute 'default nil :font "Menlo" :height 130)

(advice-add 'risky-local-variable-p :override #'ignore)

;; Increase buffers and whatnot for lsp-mode
(setq read-process-output-max (* 1024 1024)) ;; 1mb
(setq gc-cons-threshold 100000000)

(require 'jg-package)

;; Explicitly import the PATH from the shell on MacOS
(package-install 'exec-path-from-shell)
(exec-path-from-shell-initialize)

(require 'jg-core)
(require 'jg-display)
(require 'jg-style)
(require 'jg-keys)
(require 'jg-dev)
(require 'jg-org)
(require 'jg-media)

(use-package ivy
  :diminish
  :config
  (ivy-mode 1))

(use-package which-key
  :init (which-key-mode)
  :diminish which-key-mode
  :config
  (setq which-key-idle-delay 0.3))

(use-package markdown-mode
  :ensure t
  :mode ("README\\.md\\'" . gfm-mode)
  :init
  (setq markdown-asymmetric-header nil)
  (setq markdown-command "pandoc")
  (setq markdown-header-scaling t)
  (setq markdown-max-image-size '(500 . 300)))

(use-package projectile
  :diminish projectile-modex
  :config (projectile-mode)
  :bind-keymap
  ("C-c p" . projectile-command-map)
  :init
  (setq projectile-switch-project-action #'projectile-dired))

(use-package counsel-projectile
 :after projectile
 :config
 (counsel-projectile-mode 1))

(setq vc-follow-symlinks t)

(use-package auctex
  :config
  (setq TeX-auto-save t)
  (setq TeX-parse-self t))

(provide 'init)
;;; init.el ends here


