;; This is an operating system configuration template
;; for a "desktop" setup with GNOME and Xfce where the
;; root partition is encrypted with LUKS, and a swap file.

(use-modules (gnu) (gnu packages) 
	(gnu system nss)
        (gnu services)
	(srfi srfi-1)
	(guix utils))

(use-modules
	(gnu packages) 
	(nongnu packages linux) 
	(nongnu system linux-initrd))

(use-service-modules desktop sddm xorg)
(use-package-modules certs wm vim terminals)

(operating-system
  (host-name "rex")
  (timezone "Europe/Dublin")
  (locale "en_GB.utf8")
  (kernel linux)
  (initrd microcode-initrd)
  (firmware (list linux-firmware))

  ;; Choose US English keyboard layout.  The "altgr-intl"
  ;; variant provides dead keys for accented characters.
  (keyboard-layout (keyboard-layout "us" "altgr-intl"))

  ;; Use the UEFI variant of GRUB with the EFI System
  ;; Partition mounted on /boot/efi.
  (bootloader (bootloader-configuration
                (bootloader grub-efi-bootloader)
                (targets '("/boot/efi"))
                (keyboard-layout keyboard-layout)))

  ;; Specify a mapped device for the encrypted root partition.
  ;; The UUID is that returned by 'cryptsetup luksUUID'.
  (file-systems (append
                 (list (file-system
                         (device (file-system-label "my-root"))
                         (mount-point "/")
                         (type "ext4"))
                       (file-system
                         (device (uuid "F853-0BDE" 'fat))
                         (mount-point "/boot/efi")
                         (type "vfat")))
                 %base-file-systems))

  ;; Specify a swap file for the system, which resides on the
  ;; root file system.
  (swap-devices '("/dev/nvme0n1p2"))

  ;; Create user `bob' with `alice' as its initial password.
  (users (append
            (list (user-account
                    (name "jgrogan")
                    (comment "Primary User")
                    (group "users")
                    (supplementary-groups '("wheel" "netdev"
					"audio" "video"))) 
	          (user-account
                     (name "guest")
                     (comment "Guest User")
                     (group "users")
                     ))
               %base-user-accounts))

  ;; This is where we specify system-wide packages.
  (packages (append (list
		     ;; sway
		     sway
		     swaybg
		     swaylock
		     swayidle
		     wmenu
		     ;; shell and editors
		     vim
		     foot)
                    %base-packages))

  (services (append
	      (modify-services %desktop-services
			      (delete gdm-service-type))
              ;; Configure swaylock
              (list (service screen-locker-service-type
                        (screen-locker-configuration
                         (name "swaylock")
                         (program (file-append swaylock "/bin/swaylock"))
                         (using-pam? #t)
                         (using-setuid? #f)))
	       )))


  (name-service-switch %mdns-host-lookup-nss))
